:github_url:

.. _FAQ:

FAQ
===

Why?
----

Good question. Have a look at the :ref:`motivation <motivation>` section in the introduction.

What are actual use cases for this project?
-------------------------------------------

Read the section on :ref:`use cases <usecases>` in the introduction.

How does ``wenv`` work?
-----------------------

Have a closer look at the section describing the :ref:`implementation <implementation>` in the introduction.

Is ``wenv`` secure?
-------------------

Yes - limitations apply, though. See :ref:`chapter on security <security>`.

Can I use ``wenv`` for X/Y/Z fancy use case?
--------------------------------------------

`In principle`_, yes. A lot of crazy and outright amazing stuff has been attempted on top of ``wenv``, but not every idea succeeded. Solutions based on ``wenv`` or Wine for that matter tend to be a nightmare to maintain in the longer term. It is usually a good idea to stick to known-good versions of Python, Wine and related tools once you made your idea work. Plan ahead if you need to upgrade any of the involved components.

.. _In principle: https://en.wikipedia.org/wiki/Radio_Yerevan_jokes
